@@ -1,7 +1,7 @@
 from autoarray import preprocess
-from autoarray import Mask2D
 from autoarray.dataset.imaging import Imaging, SettingsImaging
 from autoarray.dataset.interferometer import Interferometer, SettingsInterferometer
+from autoarray.mask.mask_1d import Mask1D
 from autoarray.mask.mask_2d import Mask2D
 from autoarray.operators.convolver import Convolver
 from autoarray.inversion import pixelizations as pix, regularization as reg
@@ -22,9 +22,12 @@ from autoarray.structures.grids.two_d.grid_2d_irregular import Grid2DIrregular
 from autoarray.structures.grids.two_d.grid_2d_irregular import Grid2DIrregularUniform
 from autoarray.structures.grids.two_d.grid_2d_pixelization import Grid2DRectangular
 from autoarray.structures.grids.two_d.grid_2d_pixelization import Grid2DVoronoi
-from autoarray.structures.vector_fields.vector_field_irregular import VectorField2DIrregular
+from autoarray.structures.vector_fields.vector_field_irregular import (
+    VectorField2DIrregular,
+)
 from autoarray.structures.kernel_2d import Kernel2D
 from autoarray.structures.visibilities import Visibilities
+from autoarray.structures.visibilities import VisibilitiesNoiseMap
 from autogalaxy import util
 from autogalaxy.galaxy.fit_galaxy import FitGalaxy
 from autogalaxy.galaxy.galaxy import Galaxy, HyperGalaxy, Redshift
@@ -36,6 +39,7 @@ from autogalaxy.profiles import (
     light_profiles as lp,
     mass_profiles as mp,
     light_and_mass_profiles as lmp,
+    scaling_relations as sr,
 )
 from autogalaxy import convert
 
@@ -43,28 +47,26 @@ from .analysis import aggregator as agg
 from . import plot
 from .dataset.imaging import SimulatorImaging
 from .dataset.interferometer import SimulatorInterferometer
-from .dataset.point_source import PointSourceDataset
-from .dataset.point_source import PointSourceDict
+from .dataset.point_source import PointDataset
+from .dataset.point_source import PointDict
 from .fit.fit_imaging import FitImaging
 from .fit.fit_interferometer import FitInterferometer
 from .fit.fit_point_source import (
     FitPositionsSourceMaxSeparation,
     FitPositionsImage,
+    FitPositionsSource,
     FitFluxes,
+    FitPointDict,
 )
 from .lens.settings import SettingsLens
 from .lens.ray_tracing import Tracer
 from .lens.positions_solver import PositionsSolver
 from .analysis.preloads import Preloads
-from .analysis.analysis import (
-    AnalysisImaging,
-    AnalysisInterferometer,
-    AnalysisPointSource,
-)
+from .analysis.analysis import AnalysisImaging, AnalysisInterferometer, AnalysisPoint
 from autolens.analysis.setup import SetupHyper
 
 from autoconf import conf
 
 conf.instance.register(__file__)
 
-__version__ = "1.15.1"
+__version__ = "2021.6.02.1"
