@@ -6,6 +6,7 @@ import numba
 import numpy as np
 from astropy import cosmology as cosmo
 from scipy.stats import norm
+import copy
 
 import autofit as af
 from autoarray import preloads as pload
@@ -146,10 +147,38 @@ class AnalysisDataset(a.AnalysisDataset, AnalysisLensing):
 
         visualizer.visualize_stochastic_histogram(
             log_evidences=stochastic_log_evidences,
-            max_log_evidence=np.max(samples.log_likelihoods),
+            max_log_evidence=np.max(samples.log_likelihood_list),
             histogram_bins=self.settings_lens.stochastic_histogram_bins,
         )
 
+    @property
+    def no_positions(self):
+
+        # settings_lens = settings.SettingsLens(
+        # positions_threshold=None,
+        # stochastic_likelihood_resamples=self.settings_lens.stochastic_likelihood_resamples,
+        # stochastic_samples = self.settings_lens.stochastic_samples,
+        # stochastic_histogram_bins = self.settings_lens.stochastic_histogram_bins
+        # )
+        #
+        # return self.__class__(
+        #     dataset=self.dataset,
+        #     positions = None,
+        #     hyper_result=self.hyper_result,
+        #     cosmology=self.cosmology,
+        #     settings_pixelization=self.settings_pixelization,
+        #     settings_inversion=self.settings_inversion,
+        #     settings_lens=settings_lens,
+        #     preloads=self.preloads
+        # )
+
+        analysis = copy.deepcopy(self)
+
+        analysis.positions = None
+        analysis.settings_lens.positions_threshold = None
+
+        return analysis
+
 
 class AnalysisImaging(AnalysisDataset):
     @property
@@ -185,7 +214,7 @@ class AnalysisImaging(AnalysisDataset):
         )
 
         try:
-            return self.imaging_fit_for_tracer(
+            return self.fit_imaging_for_tracer(
                 tracer=tracer,
                 hyper_image_sky=hyper_image_sky,
                 hyper_background_noise=hyper_background_noise,
@@ -198,7 +227,7 @@ class AnalysisImaging(AnalysisDataset):
         ) as e:
             raise FitException from e
 
-    def imaging_fit_for_tracer(
+    def fit_imaging_for_tracer(
         self, tracer, hyper_image_sky, hyper_background_noise, use_hyper_scalings=True
     ):
 
@@ -272,7 +301,7 @@ class AnalysisImaging(AnalysisDataset):
             instance=instance
         )
 
-        fit = self.imaging_fit_for_tracer(
+        fit = self.fit_imaging_for_tracer(
             tracer=tracer,
             hyper_image_sky=hyper_image_sky,
             hyper_background_noise=hyper_background_noise,
@@ -297,7 +326,7 @@ class AnalysisImaging(AnalysisDataset):
         )
 
         if visualizer.plot_fit_no_hyper:
-            fit = self.imaging_fit_for_tracer(
+            fit = self.fit_imaging_for_tracer(
                 tracer=tracer,
                 hyper_image_sky=None,
                 hyper_background_noise=None,
@@ -328,13 +357,13 @@ class AnalysisImaging(AnalysisDataset):
             samples=samples, model=model, analysis=self, search=search
         )
 
-    def make_attributes(self):
-        return AttributesImaging(
-            cosmology=self.cosmology,
-            positions=self.positions,
-            hyper_model_image=self.hyper_model_image,
-            hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
-        )
+    def save_attributes_for_aggregator(self, paths: af.DirectoryPaths):
+
+        super().save_attributes_for_aggregator(paths=paths)
+
+        paths.save_object("psf", self.dataset.psf_unormalized)
+        paths.save_object("mask", self.dataset.mask)
+        paths.save_object("positions", self.positions)
 
 
 class AnalysisInterferometer(AnalysisDataset):
@@ -410,7 +439,7 @@ class AnalysisInterferometer(AnalysisDataset):
         )
 
         try:
-            fit = self.interferometer_fit_for_tracer(
+            fit = self.fit_interferometer_for_tracer(
                 tracer=tracer, hyper_background_noise=hyper_background_noise
             )
             return fit.figure_of_merit
@@ -460,7 +489,7 @@ class AnalysisInterferometer(AnalysisDataset):
 
         return instance
 
-    def interferometer_fit_for_tracer(
+    def fit_interferometer_for_tracer(
         self, tracer, hyper_background_noise, use_hyper_scalings=True
     ):
 
@@ -530,7 +559,7 @@ class AnalysisInterferometer(AnalysisDataset):
             instance=instance
         )
 
-        fit = self.interferometer_fit_for_tracer(
+        fit = self.fit_interferometer_for_tracer(
             tracer=tracer, hyper_background_noise=hyper_background_noise
         )
 
@@ -555,7 +584,7 @@ class AnalysisInterferometer(AnalysisDataset):
 
         if visualizer.plot_fit_no_hyper:
 
-            fit = self.interferometer_fit_for_tracer(
+            fit = self.fit_interferometer_for_tracer(
                 tracer=tracer, hyper_background_noise=None, use_hyper_scalings=False
             )
 
@@ -580,20 +609,19 @@ class AnalysisInterferometer(AnalysisDataset):
             samples=samples, model=model, analysis=self, search=search
         )
 
-    def make_attributes(self):
-        return AttributesInterferometer(
-            cosmology=self.cosmology,
-            positions=self.positions,
-            real_space_mask=self.dataset.real_space_mask,
-            hyper_model_image=self.hyper_model_image,
-            hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
-        )
+    def save_attributes_for_aggregator(self, paths: af.DirectoryPaths):
+
+        super().save_attributes_for_aggregator(paths=paths)
+
+        paths.save_object("uv_wavelengths", self.dataset.uv_wavelengths)
+        paths.save_object("real_space_mask", self.dataset.real_space_mask)
+        paths.save_object("positions", self.positions)
 
 
-class AnalysisPointSource(af.Analysis, AnalysisLensing):
+class AnalysisPoint(af.Analysis, AnalysisLensing):
     def __init__(
         self,
-        point_source_dict: ps.PointSourceDict,
+        point_dict: ps.PointDict,
         solver: psolve.PositionsSolver,
         imaging=None,
         cosmology=cosmo.Planck15,
@@ -609,7 +637,7 @@ class AnalysisPointSource(af.Analysis, AnalysisLensing):
 
         Parameters
         ----------
-        point_source_dict : ps.PointSourceDict
+        point_dict : ps.PointDict
             A dictionary containing the full point source dictionary that is used for model-fitting.
         solver : psolve.PositionsSolver
             The object which is used to determine the image-plane of source-plane positions of a model (via a `Tracer`).
@@ -628,7 +656,7 @@ class AnalysisPointSource(af.Analysis, AnalysisLensing):
             self=self, settings_lens=settings_lens, cosmology=cosmology
         )
 
-        self.point_source_dict = point_source_dict
+        self.point_dict = point_dict
 
         self.solver = solver
         self.imaging = imaging
@@ -650,53 +678,11 @@ class AnalysisPointSource(af.Analysis, AnalysisLensing):
 
         tracer = self.tracer_for_instance(instance=instance)
 
-        log_likelihood = 0.0
+        fit = fit_point_source.FitPointDict(
+            point_dict=self.point_dict, tracer=tracer, positions_solver=self.solver
+        )
 
-        for point_source_dataset in self.point_source_dict.values():
-
-            try:
-                fit_positions = self.fit_positions_for(
-                    point_source_dataset=point_source_dataset, tracer=tracer
-                )
-            except (AttributeError, numba.errors.TypingError) as e:
-                raise FitException from e
-
-            log_likelihood += fit_positions.log_likelihood
-
-            fit_fluxes = self.fit_fluxes_for(
-                point_source_dataset=point_source_dataset, tracer=tracer
-            )
-
-            if fit_fluxes is not None:
-                log_likelihood += fit_fluxes.log_likelihood
-
-        return log_likelihood
-
-    def fit_positions_for(self, point_source_dataset, tracer):
-
-        try:
-            return fit_point_source.FitPositionsImage(
-                name=point_source_dataset.name,
-                positions=point_source_dataset.positions,
-                noise_map=point_source_dataset.positions_noise_map,
-                positions_solver=self.solver,
-                tracer=tracer,
-            )
-        except exc.PointSourceExtractionException:
-            pass
-
-    def fit_fluxes_for(self, point_source_dataset, tracer):
-
-        try:
-            return fit_point_source.FitFluxes(
-                name=point_source_dataset.name,
-                fluxes=point_source_dataset.fluxes,
-                noise_map=point_source_dataset.fluxes_noise_map,
-                positions=point_source_dataset.positions,
-                tracer=tracer,
-            )
-        except exc.PointSourceExtractionException:
-            pass
+        return fit.log_likelihood
 
     def visualize(self, paths, instance, during_analysis):
 
@@ -707,42 +693,10 @@ class AnalysisPointSource(af.Analysis, AnalysisLensing):
     def make_result(
         self, samples: af.PDFSamples, model: af.Collection, search: af.NonLinearSearch
     ):
-        return res.ResultPointSource(
+        return res.ResultPoint(
             samples=samples, model=model, analysis=self, search=search
         )
 
     def save_attributes_for_aggregator(self, paths: af.DirectoryPaths):
 
-        paths.save_object("dataset", self.point_source_dict)
-
-
-class AttributesImaging(a.AttributesImaging):
-    def __init__(
-        self, cosmology, positions, hyper_model_image, hyper_galaxy_image_path_dict
-    ):
-        super().__init__(
-            cosmology=cosmology,
-            hyper_model_image=hyper_model_image,
-            hyper_galaxy_image_path_dict=hyper_galaxy_image_path_dict,
-        )
-
-        self.positions = positions
-
-
-class AttributesInterferometer(a.AttributesInterferometer):
-    def __init__(
-        self,
-        cosmology,
-        real_space_mask,
-        positions,
-        hyper_model_image,
-        hyper_galaxy_image_path_dict,
-    ):
-        super().__init__(
-            cosmology=cosmology,
-            real_space_mask=real_space_mask,
-            hyper_model_image=hyper_model_image,
-            hyper_galaxy_image_path_dict=hyper_galaxy_image_path_dict,
-        )
-
-        self.positions = positions
+        paths.save_object("dataset", self.point_dict)
