@@ -281,7 +281,7 @@ class ResultImaging(ResultDataset):
             instance=self.instance
         )
 
-        return self.analysis.imaging_fit_for_tracer(
+        return self.analysis.fit_imaging_for_tracer(
             tracer=self.max_log_likelihood_tracer,
             hyper_image_sky=hyper_image_sky,
             hyper_background_noise=hyper_background_noise,
@@ -309,7 +309,7 @@ class ResultInterferometer(ResultDataset):
             instance=self.instance
         )
 
-        return self.analysis.interferometer_fit_for_tracer(
+        return self.analysis.fit_interferometer_for_tracer(
             tracer=self.max_log_likelihood_tracer,
             hyper_background_noise=hyper_background_noise,
         )
@@ -383,7 +383,7 @@ class ResultInterferometer(ResultDataset):
         return hyper_model_visibilities
 
 
-class ResultPointSource(Result):
+class ResultPoint(Result):
     @property
     def grid(self):
         return grid_2d.Grid2D.uniform(shape_native=(100, 100), pixel_scales=0.1)
