@@ -1,53 +1,9 @@
 from autoarray.dataset import interferometer
 from autoarray.operators import transformer
 from autoarray.structures.grids.two_d import grid_2d
-from autogalaxy.dataset import interferometer as inter
 from autolens.lens import ray_tracing
 
 
-class MaskedInterferometer(interferometer.MaskedInterferometer):
-    def __init__(
-        self,
-        interferometer,
-        visibilities_mask,
-        real_space_mask,
-        settings=inter.SettingsMaskedInterferometer(),
-    ):
-        """
-        The lens dataset is the collection of data (image, noise-map), a mask, grid, convolver \
-        and other utilities that are used for modeling and fitting an image of a strong lens.
-
-        Whilst the image, noise-map, etc. are loaded in 2D, the lens dataset creates reduced 1D arrays of each \
-        for lens calculations.
-
-        Parameters
-        ----------
-        imaging: im.Imaging
-            The imaging data all in 2D (the image, noise-map, etc.)
-        real_space_mask: msk.Mask2D
-            The 2D mask that is applied to the image.
-        sub_size : int
-            The size of the sub-grid used for each lens SubGrid. E.g. a value of 2 grid each image-pixel on a 2x2 \
-            sub-grid.
-        positions : [[]]
-            Lists of image-pixel coordinates (arc-seconds) that mappers close to one another in the source-plane(s), \
-            used to speed up the non-linear sampling.
-        pixel_scales_interp : float
-            If `True`, expensive to compute mass profile deflection angles will be computed on a sparse grid and \
-            interpolated to the grid, sub and blurring grids.
-        inversion_pixel_limit : int or None
-            The maximum number of pixels that can be used by an inversion, with the limit placed primarily to speed \
-            up run.
-        """
-
-        super(MaskedInterferometer, self).__init__(
-            interferometer=interferometer,
-            visibilities_mask=visibilities_mask,
-            real_space_mask=real_space_mask,
-            settings=settings,
-        )
-
-
 class SimulatorInterferometer(interferometer.SimulatorInterferometer):
     def __init__(
         self,
@@ -111,9 +67,9 @@ class SimulatorInterferometer(interferometer.SimulatorInterferometer):
             A seed for random noise_maps generation
         """
 
-        image = tracer.image_from_grid(grid=grid)
+        image = tracer.image_2d_from_grid(grid=grid)
 
-        return self.from_image(image=image.slim_binned, name=name)
+        return self.from_image(image=image.binned, name=name)
 
     def from_galaxies_and_grid(self, galaxies, grid, name=None):
         """Simulate imaging data for this data, as follows:
@@ -143,8 +99,8 @@ class SimulatorInterferometer(interferometer.SimulatorInterferometer):
             sub_size=1,
         )
 
-        deflected_grid = grid - deflections.slim_binned
+        deflected_grid = grid - deflections.binned
 
-        image = sum(map(lambda g: g.image_from_grid(grid=deflected_grid), galaxies))
+        image = sum(map(lambda g: g.image_2d_from_grid(grid=deflected_grid), galaxies))
 
         return self.from_image(image=image, name=name)
