@@ -1,3 +1,10 @@
+from autofit.plot.samples_plotters import SamplesPlotter
+from autofit.plot.dynesty_plotter import DynestyPlotter
+from autofit.plot.ultranest_plotter import UltraNestPlotter
+from autofit.plot.emcee_plotter import EmceePlotter
+from autofit.plot.zeus_plotter import ZeusPlotter
+from autofit.plot.pyswarms_plotter import PySwarmsPlotter
+
 from autoarray.plot.mat_wrap.wrap.wrap_base import (
     Units,
     Figure,
@@ -34,7 +41,6 @@ from autoarray.plot.mat_wrap.wrap.wrap_2d import (
 )
 
 from autoarray.plot.structure_plotters import Array2DPlotter
-from autoarray.plot.structure_plotters import Frame2DPlotter
 from autoarray.plot.structure_plotters import Grid2DPlotter
 from autoarray.plot.structure_plotters import MapperPlotter
 from autoarray.plot.structure_plotters import YX1DPlotter
