@@ -35,7 +35,7 @@ The mass-profile and source light profile in this example have fixed centre (0.0
 lensing geometries.
 """
 
-mass_profile_model = af.PriorModel(al.mp.EllipticalIsothermal)
+mass_profile_model = af.Model(al.mp.EllIsothermal)
 
 mass_profile_model.centre.centre_0 = af.UniformPrior(lower_limit=-1.0, upper_limit=1.0)
 mass_profile_model.centre.centre_0 = af.UniformPrior(lower_limit=-1.0, upper_limit=1.0)
@@ -47,7 +47,7 @@ mass_profile_model.elliptical_comps.elliptical_comps_1 = af.UniformPrior(
 )
 mass_profile_model.einstein_radius = af.UniformPrior(lower_limit=0.3, upper_limit=2.0)
 
-light_profile_model = af.PriorModel(al.lp.EllipticalExponential)
+light_profile_model = af.Model(al.lp.EllExponential)
 light_profile_model.centre.centre_0 = af.UniformPrior(lower_limit=-1.0, upper_limit=1.0)
 light_profile_model.centre.centre_1 = af.UniformPrior(lower_limit=-1.0, upper_limit=1.0)
 light_profile_model.elliptical_comps.elliptical_comps_0 = 0.2
@@ -76,13 +76,13 @@ for i in range(iters):
 
     light_profile = light_profile_model.random_instance()
 
-    """Setup the lens, source and _Tracer_."""
+    """Setup the lens, source and `Tracer`."""
 
     lens_galaxy = al.Galaxy(redshift=0.5, mass=mass_profile)
     source_galaxy = al.Galaxy(redshift=1.0, light=light_profile)
     tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
 
-    """Solve for the positions via the _Tracer_."""
+    """Solve for the positions via the `Tracer`."""
 
     positions = solver.solve(
         lensing_obj=tracer,
@@ -94,7 +94,7 @@ for i in range(iters):
     visuals_2d = aplt.Visuals2D(positions=positions)
 
     tracer_plotter = aplt.TracerPlotter(tracer=tracer, grid=grid, visuals_2d=visuals_2d)
-    tracer_plotter.figures(image=True)
+    tracer_plotter.figures_2d(image=True)
 
     """Save the `Tracer` and `Positions` so they can be used for testing other `PositionsSolver` settings."""
 
